-- ----------------------------
-- 审计记录表
-- ----------------------------
create table t_audit (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  `year`            year          comment '年份',
  pre_audit_time    datetime      comment '预审时间',
  audit_time        datetime      comment '审计时间',
  audit_result      varchar(500)  comment '审计结果',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '审计记录表';

-- ----------------------------
-- 装置信息表
-- ----------------------------
create table t_dept_info (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  `year`            year          comment '年份',
  dept_info         varchar(500)  comment '装置信息',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '装置信息表';

-- ----------------------------
-- 章节表
-- ----------------------------
create table t_chapter (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  audit_id          bigint(20)    comment '审计记录id',
  code              varchar(8)    comment '序号',
  name              varchar(500)  comment '名称',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '章节表';

-- ----------------------------
-- 章节模板表
-- ----------------------------
create table t_chapter_template (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  code              varchar(8)    comment '序号',
  name              varchar(500)  comment '名称',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '章节模板表';

-- ----------------------------
-- 问卷表
-- ----------------------------
create table t_questionnaire (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  audit_id          bigint(20)    comment '审计记录id',
  chapter_id        bigint(20)    comment '章节id',
  year              year          comment '年份',
  type              char(1)       comment '问卷类型',
  directory         varchar(500)  comment '目录',
  code              bigint(20)    comment '序号',
  name              varchar(500)  comment '名称',
  yes_no_na         char(1)       comment 'YES/NO/NA',
  minimum_standard  varchar(500)  comment 'MinimumStandard',
  good_practices    varchar(500)  comment 'Good Practices',
  standard         char(1)        comment '标准',
  completion_status char(1)       comment '完成情况',
  person_in_charge  bigint(20)    comment '负责人',
  reviewer          bigint(20)    comment '审核人',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '问卷表';

-- ----------------------------
-- 问卷模板表
-- ----------------------------
create table t_questionnaire_template (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  chapter_id        bigint(20)    comment '章节id',
  type              char(1)       comment '问卷类型',
  directory         varchar(500)  comment '目录',
  code              bigint(20)    comment '序号',
  name              varchar(500)  comment '名称',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '问卷模板表';

-- ----------------------------
-- 进度表
-- ----------------------------
create table t_progress (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  questionnaire_id   bigint(20)   comment '问卷id',
  chap_name         varchar(500)  comment '章节',
  sub_chap_name     varchar(500)  comment '细分章节',
  sec_sub_chap_name varchar(500)  comment '二级细分章节',
  content           varchar(500)  comment '内容',
  person_in_charge  bigint(20)    comment '负责人',
  supporter         bigint(20)    comment '支持人',
  start_date        datetime      comment '开始日期',
  target_date       datetime      comment '目标日期',
  finish_date       datetime      comment '实际完成日期',
  preparation       char(1)       comment '准备情况',
  description          char(1)    comment '进度描述',
  apply_status      char(1)       comment '审批状态',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  audit_id          bigint(20)    comment '审计记录id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '进度表';

-- ----------------------------
-- 会议表
-- ----------------------------
create table t_meeting (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  year              year          comment '年份',
  questionnaire_id   bigint(20)   comment '涉及code',
  person_in_charge  bigint(20)    comment '负责人',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '会议表';

-- ----------------------------
-- 开项表
-- ----------------------------
create table t_open_item (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  type              char(1)       comment '问题类型',
  questionnaire_id   bigint(20)   comment '涉及整改code',
  description       varchar(500)  comment '存在问题描述',
  level             char(1)       comment '开项级别',
  open_time         datetime      comment '开项时间',
  close_time        datetime      comment '闭项时间',
  status            char(1)       comment '问题处理状态',
  person_in_charge  bigint(20)    comment '负责人',
  reviewer          bigint(20)    comment '审核人',
  result            char(1)       comment '责任人确认',
  deadline          datetime      comment '截至时间',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '开项表';

-- ----------------------------
-- 通用附件表
-- ----------------------------
create table t_commonfile
(
  id bigint(20) comment 'id' not null auto_increment,
  p_id bigint(20) comment '业务id',
  file_name varchar(255) comment '文件名',
  file_url varchar(500) comment '路径',
  del_flag bigint(20) default 0 comment '删除标识',
  creater_code varchar(255) comment '创建人',
  createdate datetime comment '创建时间',
  updater_code varchar(255) comment '更新人',
  updatedate datetime comment '更新时间',
  remarks varchar(255) comment '备注',
  p_type varchar(64) comment '业务类型',
  file_size varchar(128) comment '文件大小',
  p_value varchar(1000) comment '业务字段',
  p_date datetime comment '业务时间',
	primary key (id)
) engine=innodb auto_increment=100 comment = '通用附件表';